// Required libraries
#include <avr/io.h>
#include <util/delay.h>
#include <avr/interrupt.h>
#include "uart.h"

#define CLK  PD5  // CLK -> pin 5 
#define DIO  PD4  // DIO -> pin 4 


#define set_bit(ADDRESS,BIT) (ADDRESS |= (1<<BIT))
#define clear_bit(ADDRESS,BIT) (ADDRESS &= ~(1<<BIT))


#define LEFT_START_STOP_PIN PD2 // Tlacidlo pre lavy tim
#define RIGHT_START_STOP_PIN PD3 // Tlacidlo pre pravy tim
#define RESTART_PIN PD6 // Tlacidlo na vynulovanie skore





volatile uint8_t count_left = 0;  // Pocitadlo skore pre lavu dvojicu 7 segmentoviek
volatile uint8_t count_right = 0; // Pocitadlo skore pre pravu dvojicu 7 segmentoviek



// External interrupt 0 (Tlacidlo pre lavy tim)
ISR (INT0_vect)
{
	

    _delay_ms(10);
    if(bit_is_clear(PIND, LEFT_START_STOP_PIN)){
        // Zvysuje skore laveho time a pri dosiahnuti hodnoty 100 zresetuje hodnotu na 0
        count_left++;
		
        if (count_left >= 100) count_left = 0;
    }
    _delay_ms(150);
}

// External interrupt 1 (tlacidlo pre pravy tim)
ISR (INT1_vect)
{
    _delay_ms(10);
    if(bit_is_clear(PIND, RIGHT_START_STOP_PIN)){
        // Zvysuje skore praveho time a pri dosiahnuti hodnoty 100 zresetuje hodnotu na 0
        count_right++;
        if (count_right >= 100) count_right = 0;
    }
    _delay_ms(150);
}


int main(void){
    
    clear_bit(DDRD, CLK);  // Nastavenie CLK ako input
    set_bit(PORTD, CLK);   // CLK ako input pull-up on
    
    clear_bit(DDRD, DIO);  // Nastavenie DIO ako input
    set_bit(PORTD, DIO);   // DIO ako input pull-up o
    
    clear_bit(DDRD, LEFT_START_STOP_PIN);   // Nastavenie LEFT_START_STOP_PIN ako input
    set_bit(PORTD, LEFT_START_STOP_PIN);    // LEFT_START_STOP_PIN ako input pull-up on
    
    clear_bit(DDRD, RIGHT_START_STOP_PIN);  // Nastavenie RIGHT_START_STOP_PIN ako input
    set_bit(PORTD, RIGHT_START_STOP_PIN);   // RIGHT_START_STOP_PIN ako input pull-up on
	
	clear_bit(DDRD, RESTART_PIN);  // Nastavenie RESET_PIN ako input
	set_bit(PORTD, RESTART_PIN);  // RESET_PIN ako input pull-up on
	
    uint8_t data[] = { 0, 0, 0, 0 };
    set_segments(data, 4, 0);

    
    EIMSK = 0b00000011; // Povolenie INT0, INT1
    EICRA = 0b00001010;       // Zaznamenanie dobeznej hrany na oboch pinoch
    
    sei();  // Povolit prerusenia
    

    
    while (1) {
		if (bit_is_clear(PIND, RESTART_PIN)) {
			// Spusti reset
			
			count_left = 0; // Resetuje skore laveho timu
			count_right = 0; // Resetuje skore praveho timu
			
			}

			// Zobrazenie skore laveho timu na lavych 2 7 segmentovkach a skore praveho timu na pravych 2 7 segmentovkach
			
			display_number_segment(count_right, 0, 2, 2);
			
			display_number_segment(count_left, 0, 2, 0);

    }
    
    return 0;
}